# Dash AgGrid Scales

Plotly color scales for columns in `dash-ag-grid`

This package provides three main scales to highlight values in AgGrid columns. For consistency, the names use the same conventions use by the `plotly.colors` module:

- sequential
- qualitative
- bar

![](grid_with_color_scales.png)
